@@ -813,3 +813,45 @@ def get_total_occurrence_times_by_keywords(total_qs_ls, search_field_ls, keyword
     return ret
 
 
+def get_statistic_fields_result(queryset, statistic_fields, statistic_size=5, descend=True):
+    """
+    # 统计字段 fields 的值各出现了几次
+    - statistic_fields 为迭代型时(如[name, id]), 只统计第一个字段, 然后将第二个字段用filter补上一个值
+    """
+
+    assert isinstance(statistic_fields, list), 'statistic_fields必须为list类型!'
+    statistic_size = int(statistic_size)
+
+    if descend:
+        ordering = ['-counts']
+    else:
+        ordering = ['counts']
+
+    statistic_dc = {}
+    for field in statistic_fields:
+        # break
+        if isinstance(field, (tuple, list)):
+            # field_qsv = queryset.values(*field)
+            field_qsv = queryset.values(field[0])
+            dc_name = field[0]
+        else:
+            field_qsv = queryset.values(field)
+            dc_name = field
+        statistic_qsv = field_qsv.annotate(counts=m.Count('pk')).order_by(*ordering)
+        dc_ls = list(statistic_qsv[:statistic_size])
+
+        for dc in dc_ls:
+            if isinstance(field, (tuple, list)):
+                dc['name'] = dc.pop(field[0])
+                f_name = field[1]
+                f_value = queryset.filter(**{field[0]: dc['name']}).order_by(f_name).values(f_name)[0].get(f_name)
+                dc[f_name] = f_value
+            else:
+                dc['name'] = dc.pop(field)
+        dc = {
+            dc_name: dc_ls
+        }
+        statistic_dc.update(dc)
+    return statistic_dc
+
+
